===============================
closeio
===============================

.. image:: https://travis-ci.org/Thermondo/closeio.png?branch=master
    :target: https://travis-ci.org/Thermondo/closeio

.. image:: https://coveralls.io/repos/Thermondo/closeio/badge.png?branch=master
    :target: https://coveralls.io/r/Thermondo/closeio

.. image:: https://pypip.in/v/faster_closeio/badge.png
    :target: https://crate.io/packages/faster_closeio

.. image:: https://pypip.in/status/faster_closeio/badge.svg
    :target: https://pypi.python.org/pypi/faster_closeio/
    :alt: Development Status

.. image:: https://pypip.in/py_versions/faster_closeio/badge.svg
    :target: https://pypi.python.org/pypi/faster_closeio/
    :alt: Supported Python versions

.. image:: https://pypip.in/d/faster_closeio/badge.png
    :target: https://crate.io/packages/faster_closeio/
    :alt: Downloads

.. image:: https://pypip.in/license/faster_closeio/badge.png
    :target: https://pypi.python.org/pypi/faster_closeio/
    :alt: License


Slim API wrapper to access close.io CRM

* Free software: BSD license
* Documentation: http://closeio.rtfd.org.

Features
--------

* TODO
